@@ -1,7 +1,6 @@
 #!/usr/bin/env python3
 # SPDX-License-Identifier: MIT
 
-from base64 import b64decode
 from pyroute2.netlink import nla_base
 
 class key(nla_base):
@@ -19,11 +18,4 @@ class key(nla_base):
         nla_base.decode(self)
         self.value = self['value'] if self['value'] != bytes(32) else None
 
-    @staticmethod
-    def frob(nitz):
-        if not isinstance(nitz, (bytes, bytearray)):
-            nitz = b64decode(nitz)
-
-        return nitz
-
 #
